@@ -1,4 +1,4 @@
-# Copyright (C) 2015-2019  The Software Heritage developers
+# Copyright (C) 2015-2021  The Software Heritage developers
 # See the AUTHORS file at the top-level directory of this distribution
 # License: GNU General Public License version 3, or any later version
 # See top-level LICENSE file for more information
@@ -10,6 +10,8 @@ from subprocess import run
 import tarfile
 import zipfile
 
+import magic
+
 from . import utils
 
 
@@ -73,6 +75,16 @@ def register_new_archive_formats():
         shutil.register_unpack_format(name, extensions, function)
 
 
+_mime_to_archive_format = {
+    "application/x-compress": "tar.Z|x",
+    "application/x-tar": "tar",
+    "application/x-bzip2": "bztar",
+    "application/gzip": "gztar",
+    "application/x-lzip": "tar.lz",
+    "application/zip": "zip",
+}
+
+
 def uncompress(tarpath: str, dest: str):
     """Uncompress tarpath to dest folder if tarball is supported.
 
@@ -91,15 +103,21 @@ def uncompress(tarpath: str, dest: str):
     try:
         os.makedirs(dest, exist_ok=True)
         format = None
+        # try to get archive format from extension
         for format_, exts, _ in shutil.get_unpack_formats():
             if any([tarpath.lower().endswith(ext.lower()) for ext in exts]):
                 format = format_
                 break
+        # try to get archive format from file mimetype
+        if format is None:
+            m = magic.Magic(mime=True)
+            mime = m.from_file(tarpath)
+            format = _mime_to_archive_format.get(mime)
         shutil.unpack_archive(tarpath, extract_dir=dest, format=format)
     except shutil.ReadError as e:
         raise ValueError(f"Problem during unpacking {tarpath}. Reason: {e}")
     except NotImplementedError:
-        if tarpath.lower().endswith(".zip"):
+        if tarpath.lower().endswith(".zip") or format == "zip":
             _unpack_zip(tarpath, dest)
         else:
             raise
